Attribute VB_Name = "MLXIO_IMPORT_LIBRARY"
'*************************************************
'   MLXIO.BAS
'
'   Import library to write Visual Basic programs
'   with the SORCUS MLXIO.DLL
'
'   Operating Systems:  Windows 3.x
'                       Windows 95
'                       Windows NT
'
'   Author:             Dipl.-Ing. M.Sailer
'
'   (C) SORCUS Computer GmbH 1999, 2000
'*************************************************
'
'*************************************************



'*************************************************
'   Constants
'*************************************************

Public Const MAX_CARDS = 8

' return values from mlxio_get_acquisition_state
Public Const MLXIO_STOPPED = 0
Public Const MLXIO_WAITING = 1
Public Const MLXIO_RUNNING = 2
Public Const MLXIO_TRIGSTOP = 3
Public Const MLXIO_BLOCKEND = 4

' Constants for parameter 'mode' in mlxio_initialize (to be 'ored')
Public Const MLXIO_CONTINUOUS = &H1
Public Const MLXIO_BLOCK = &H0
Public Const MLXIO_INPUT_FLEX = &H2
Public Const MLXIO_OUTPUT_FLEX = &H4
Public Const MLXIO_INPUT_FAST = &H0
Public Const MLXIO_OUTPUT_FAST = &H0
Public Const MLXIO_OUTPUT_REPEAT = &H8

' Error values: (return values of several functions)
Public Const MLXIO_OK = 0
Public Const MLXIO_ERR_MDDPATH = 1
Public Const MLXIO_ERR_INVALID_STATE = 2
Public Const MLXIO_ERR_LOAD_DRIVER = 3
Public Const MLXIO_ERR_MDD_OPEN = 4
Public Const MLXIO_ERR_MLXM_OPEN = 5
Public Const MLXIO_ERR_PREPARE = 6
Public Const MLXIO_ERR_START = 7
Public Const MLXIO_ERR_CHANNEL_TYPE = 8
Public Const MLXIO_ERR_TRIGGERTASK = 9
Public Const MLXIO_ERR_OPEN_TRIGGER = 10
Public Const MLXIO_ERR_OPEN_SAMPTRIG = 11
Public Const MLXIO_ERR_PRETRIGGER = 12
Public Const MLXIO_ERR_INVALID_HANDLE = 13
Public Const MLXIO_ERR_SAMPLE_RATE = 14
Public Const MLXIO_ERR_MEMORY = 15
Public Const MLXIO_ERR_TOO_MUCH_OUTPUTS = 16
Public Const MLXIO_ERR_TOO_INVALID_CHANNEL = 17
Public Const MLXIO_ERR_RELOAD = 32
Public Const MLXIO_ERR_OPEN_INPUT = 48
Public Const MLXIO_ERR_OPEN_OUTPUT = 64
Public Const MLXIO_ERR_NEXT = 80

' output values of parameter 'error' in mlxio_read_data/mlxio_write_data
Public Const MLXIO_BUF_OVERFLOW = &H1
Public Const MLXIO_BUF_SPACE = &H2
Public Const MLXIO_BUF_TRANSFER = &H4

' parameter 'action' in trigger definition functions
Public Const TRIGACT_START = 0
Public Const TRIGACT_STOP = 1

' parameter 'mode' in mlxio_define_limit_trigger
Public Const TRIGMODE_LIMIT_GT = 0
Public Const TRIGMODE_LIMIT_LT = 1

' parameter 'mode' in mlxio_define_bitmask_trigger
Public Const TRIGMODE_ONE_BIT_SET = &H0
Public Const TRIGMODE_ONE_BIT_CLR = &H1
Public Const TRIGMODE_ALL_BITS_SET = &H80
Public Const TRIGMODE_ALL_BITS_CLR = &H81

'************************************************************************
'*      mlxio_set_driver_path
'*
'*      PURPOSE
'*      sets path where to find MDDs. If not specified,
'*  registry is searched for HKEY_LOCAL_MACHINE\SOFTWARE\SORCUS\SNW32
'*  ml?_mdd_path
'*
'*      PARAMETER
'*      -       path            Pointer to string containing path name
'*
'*      RETURN
'*      none
'*
'************************************************************************
Declare Sub mlxio_set_driver_path Lib "mlxio.dll" _
(ByVal path As String)

'*************************************************************************
'*      mlxio_initialize
'*
'*      PURPOSE
'*      initializes measurement parameters:
'*      -       freq:           base frequency for data acquisition
'*      -       bufsize: length of data buffer for each channel
'*      -  mode:                not defined yet, please set to 0
'*
'*      PARAMETER
'*
'*      RETURN
'*      none
'*
'*************************************************************************
Declare Function mlxio_initialize _
Lib "mlxio.dll" _
(ByVal freq As Double, ByVal bufsize As Long, ByVal mode As Long) As Long

'*************************************************************************
'*      mlxio_open_input_channel
'*
'*      PURPOSE
'*      opens a MDD channel and allocates a ring buffer.
'*************************************************************************
Declare Function mlxio_open_input_channel Lib "mlxio.dll" _
(ByVal usMDD As Integer, ByVal usStrucSize As Integer, _
ByRef pCPS As Any, ByVal rate As Integer) As Long

'*************************************************************************
'*      mlxio_open_output_channel
'*
'*      PURPOSE
'*      opens a MDD channel and allocates a ring buffer.
'*************************************************************************
Declare Function mlxio_open_output_channel Lib "mlxio.dll" _
(ByVal usMDD As Integer, ByVal usStrucSize As Integer, _
ByRef pCPS As Any, ByVal rate As Integer) As Long

'*************************************************************************
'*	mlxio_open_sample_trigger
'*
'*	PURPOSE
'*	opens a sample trigger channel for the specified module.
'*   The module is triggered at the beginning of the sample cycle.
'*************************************************************************
Declar Function mlxio_open_sample_trigger Lib "mlxio.dll" _
(ByVal usMDD As Integer, ByVal usStrucSize As Integer, _
ByRef pCPS As Any, ByVal rate As Integer, ByVal trigval As Long) As Long

'*************************************************************************
'*      mlxio_get_mdd_handle
'*
'*      PURPOSE
'*      returns handle of attached MDD channel
'*************************************************************************
Declare Function mlxio_get_mdd_handle Lib "mlxio.dll" _
(ByVal hmlxio As Long) As Long

'*************************************************************************
'*      mlxio_get_data_size
'*
'*      PURPOSE
'*      returns number of bytes per sample for specified channel
'*************************************************************************
Declare Function mlxio_get_data_size Lib "mlxio.dll" _
(ByVal hmlxio As Long) As Long

'*************************************************************************
'*      mlxio_write_data
'*
'*      PURPOSE
'*      write a data block of output samples into ring buffer.
'*      When all previously opened buffers contain output data,
'*      bundled blocks are transfered to the board
'**************************************************************************
Declare Function mlxio_write_data Lib "mlxio.dll" _
(ByVal hmlxio As Long, ByRef databuffer As Any, _
ByVal numofbytes As Long, ByRef error As Long) As Long

'*************************************************************************
'*      mlxio_read_data
'*
'*      PURPOSE
'*      read data block from ring buffer. Ring buffer is automatically
'*      filled under interrupt control
'*************************************************************************
Declare Function mlxio_read_data Lib "mlxio.dll" _
(ByVal hmlxio As Long, ByRef databuffer As Any, _
ByVal numofbytes As Long, ByRef error As Long, _
ByRef timebase As Long) As Long

'*************************************************************************
'*      mlxio_start_measurement
'*
'*      PURPOSE
'*      start data acquisition directly or begins waiting for start
'*  trigger event (if one is defined)
'*************************************************************************
Declare Function mlxio_start_measurement Lib "mlxio.dll" _
() As Long

'*************************************************************************
'*      mlxio_stop_measurement
'*
'*      PURPOSE
'*      stop data acquisition
'*************************************************************************
Declare Function mlxio_stop_measurement Lib "mlxio.dll" _
() As Long

'*************************************************************************
'*      mlxio_get_acquisition_state
'*
'*      PURPOSE
'*      returns state of data acquisition
'*  0:      stopped by mlxio_stop_measurement or not started yet
'*  1:      waiting for start trigger
'*  2:      data acquisition running
'*  3:      data acquisition stopped by stop trigger
'*************************************************************************
Declare Function mlxio_get_acquisition_state Lib "mlxio.dll" _
() As Long

'*************************************************************************
'*      mlxio_get_channel_state
'*
'*      PURPOSE
'*      returns free/used space and error state
'*************************************************************************
Declare Sub mlxio_get_channel_state Lib "mlxio.dll" _
(ByVal hmlxio As Long, ByRef free As Long, _
ByRef used As Long, ByRef error As Long)

'*************************************************************************
'*      mlxio_close_channel
'*
'*      PURPOSE
'*      close any previously opened channel.
'*  Channel can be of type HMLXIO, HMLXTRIG or HMDD8
'*************************************************************************
Declare Sub mlxio_close_channel Lib "mlxio.dll" _
(ByVal hmlxio As Long)

'*************************************************************************
'*      mlxio_set_trigger_mode
'*
'*      PURPOSE
'*      specify pre- and posttrigger times (in units of base sampling rate
'*  defined in mlxio_initialize)
'*
'*      globstart: 0:  trigger event starts/stops acquisition on actual board
'*                              1:  trigger event starts/stops acquisition on all used boards
'*
'*
'*************************************************************************
Declare Sub mlxio_set_trigger_mode Lib "mlxio.dll" _
(ByVal pretrigger As Long, ByVal posttrigger As Long, _
ByVal globstart As Long)

'*************************************************************************
'*      mlxio_define_limit_trigger
'*
'*      PURPOSE
'*      creates a trigger object checking an analog trigger signal.
'*
'*  hSignal:     Handle of the channel to be checked:
'*                               can be a previously opened input signal
'*                               (handle of type HMLXIO, returned by mlxio_open_input_channel)
'*                               or a handle returned by mdd8_open_channel.
'*  action:   0x00  (TRIGACT_START)        trigger event starts acquisition
'*                               0x01  (TRIGACT_STOP)         trigger event stops acquisition
'*  mode:     0     (TRIGMODE_LIMIT_GT)    check if analog signal is greater
'*                                                                                                              than specified limit
'*                               1     (TRIGMODE_LIMIT_LT)    check if analog signal is less
'*                                                                                                              than specified limit
'*      limit:   value to be checked for.
'*                               if trigger_mode TRIGMODE_LIMIT_GT is specified, this value
'*                               must be exceeded to cause a trigger event.
'*  min_time: 0:  exceeding limit immediately causes trigger event
'*                               >0: trigger condition must be true for min. base clock ticks
'*                                        before trigger event is generated.
'*  hysteresis:
'*                               e.g. trigger_mode = TRIGMODE_LIMIT_GT: if a value
'*                               less than 'limit' is specified, signal must return to
'*                               'hysteresis' value before the next trigger event can be
'*                               generated. if 'hysteresis' is equal to or greater than
'*                               'limit', no hysteresis check is performed.
'*
'*      return value:   0    : could not create trigger object
'*                 != 0 : handle of trigger object
'*
'*************************************************************************
Declare Function mlxio_define_limit_trigger Lib "mlxio.dll" _
(ByVal hSignal As Long, ByVal action As Integer, _
ByVal mode As Integer, ByVal limit As Integer, _
ByVal min_time As Integer, ByVal hysteresis As Integer) _
As Long

'*************************************************************************
'*      mlxio_define_bitmask_trigger
'*
'*      PURPOSE
'*      creates a trigger object checking a group of digital signals.
'*
'*  hSignal:     Handle of the channel to be checked:
'*                               can be a previously opened input signal
'*                               (handle of type HMLXIO, returned by mlxio_open_input_channel)
'*                               or a handle returned by mdd8_open_channel.
'*
'*  action:   0x00  (TRIGACT_START)        trigger event starts acquisition
'*                               0x01  (TRIGACT_STOP)         trigger event stops acquisition
'*
'*  mode:     0x00  (TRIGMODE_ONE_BIT_SET)       check if at least one bit (specified
'*                                                                                                               in bitmask) is set in the signal block
'*                               0x01  (TRIGMODE_ONE_BIT_CLR)    check if at least one bit (specified
'*                                                                                                               in bitmask) is cleared in signal block
'*                               0x80  (TRIGMODE_ALL_BITS_SET) check if all bits (specified in
'*                                                                                                               bitmask) are set in the signal block
'*                               0x81  (TRIGMODE_ALL_BITS_CLR) check if all bits (specified in
'*                                                                                                               bitmask) are cleared in signal block
'*
'*  bitmask:  compare value
'*
'*  min_time: 0:  bitmask match immediately causes trigger event
'*                               >0: trigger condition must be true for min. base clock ticks
'*                                        before trigger event is generated.
'*
'*      return value:   0    : could not create trigger object
'*                 != 0 : handle of trigger object
'*
'*************************************************************************
Declare Function mlxio_define_bitmask_trigger Lib "mlxio.dll" _
(ByVal hSignal As Long, ByVal action As Integer, _
ByVal mode As Integer, ByVal bitmask As Integer, _
ByVal min_time As Integer) As Long

'*************************************************************************
'*      mlxio_define_trigger
'*
'*      PURPOSE
'*      creates a trigger object based on a CPS-structure for the trigger MDD.
'*  (for SORCUS internal use only!)
'*
'*  hSignal:     Handle of the channel to be checked:
'*                               can be a previously opened input signal
'*                               (handle of type HMLXIO, returned by mlxio_open_input_channel)
'*                               or a handle returned by mdd8_open_channel.
'*
'*  sizecps:  length (in bytes) of cps structure
'*
'*  pcps:                pointer to cps structure for trigger MDD
'*
'*      return value:   0    : could not create trigger object
'*                 != 0 : handle of trigger object
'*
'*************************************************************************
Declare Function mlxio_define_trigger Lib "mlxio.dll" _
(ByVal hSignal As Long, ByVal size_cps As Integer, ByRef pCPS As Any) _
As Long

'*************************************************************************
'*      mlxio_reload
'*
'*      PURPOSE
'*      opens all configured channels on selected board
'*************************************************************************
Declare Function mlxio_reload Lib "mlxio.dll" () As Long

'*************************************************************************
'*      mlxio_close_all
'*
'*      PURPOSE
'*      free all resources used by MLXIO.DLL
'*************************************************************************
Declare Function mlxio_close_all Lib "mlxio.dll" () As Long

'*************************************************************************
'*      mlxio_reset_error
'*
'*      PURPOSE
'*      resets error state of an I/O channel
'*************************************************************************
Declare Sub mlxio_reset_error Lib "mlxio.dll" _
(ByVal hmlxio As Long)

'*************************************************************************
'*	mlxio_set_private_data
'*
'*	PURPOSE
'*	user program can save a 32-bit-value for each I/O channel to identify
'*  it in callback functions
'************************************************************************/
Declare Sub mlxio_set_private_data Lib "mlxio.dll" _
(ByVal hmlxio As Long, ByVal ulPrivate As Long)

'*************************************************************************
'*	mlxio_get_private_data
'*
'*	PURPOSE
'*	read back private 32-bit-value of I/O channel
'*************************************************************************
Declare Function mlxio_get_private_data Lib "mlxio.dll" _
(ByVal hmlxio As Long) As Long

'*************************************************************************
'*	mlxio_get_previous_error
'*
'*	PURPOSE
'*	returns the error state of the previous open-function.
'*	Can be called after an open-function has returned a NULL handle
'*************************************************************************
Declare Function mlxio_get_previous_error Lib "mlxio.dll" () As Long
