/************************************************************************
*
*                          MLXIO.H
*
*               header file for data acquisition DLL
*			 Further information about this library can be found
*						in SORCUS application note 068
*                                                                      
*					      version      : see history                 
*							creation 	 : 12.05.99
*							last change  : see history
*							author       : M.Sailer
*
* 		(c) by SORCUS Computer GmbH Heidelberg 1999
*************************************************************************/

/************************************************************************
*
*	software requirements:
*		- SORCUS I/O port drivers for Multi-LAB/2 or Modular-4/486
*		- library MLXW32.DLL
*		- library MLXIO.DLL
*		- additional OSX programs as listed in SORCUS application note 068
*
*************************************************************************/

/************************************************************************
*  history:
*   	1.A.000 12.05.99
*        - creation of the file
*		1.A.001 26.06.99
*			- some modifications made for LabView
*		1.A.002 28.09.99
*			- source code of additional library MLXMEAS.DLL has been
*			  integrated into MLXIO.DLL
*			- restarting measurement now works properly
*
*************************************************************************/

#ifndef MLXIO_DEFINED
#define MLXIO_DEFINED    1
                
#ifdef _WIN32
                
#ifdef PROJECT_MLXIO
#define MLXIO_API    __declspec(dllexport)
#else
#define MLXIO_API    __declspec(dllimport)
#endif

#define MLXIO_FUNC   __stdcall

#define	MLXIO_CALLBACK	__stdcall

#else

#ifdef PROJECT_MLXIO
#define	MLXIO_FUNC	FAR PASCAL __export
#else
#define	MLXIO_FUNC	FAR PASCAL
#endif            

#define	MLXIO_CALLBACK	FAR PASCAL __export

#define MLXIO_API

#endif

#ifdef __cplusplus
extern "C"{
#endif
/*************************************************************************
*           definitions
*************************************************************************/

typedef void* HMLXIO;
typedef void* HMLXTRIG;
typedef void* HSAMPTRIG;

/*************************************************************************
*           data types
*************************************************************************/

#define MAX_CARDS 8

enum
{
	MLXIO_STOPPED,
	MLXIO_WAITING,
	MLXIO_RUNNING,
	MLXIO_TRIGSTOP,
	MLXIO_BLOCKEND,
	MLXIO_ERRORSTOP
};

#define	MLXIO_CONTINUOUS	0x0001
#define	MLXIO_BLOCK			0x0000
#define	MLXIO_INPUT_FLEX	0x0002
#define	MLXIO_OUTPUT_FLEX	0x0004
#define	MLXIO_INPUT_FAST	0x0000
#define	MLXIO_OUTPUT_FAST	0x0000
#define	MLXIO_OUTPUT_REPEAT 0x0008

enum
{
	MLXIO_OK,
	MLXIO_ERR_MDDPATH,
	MLXIO_ERR_INVALID_STATE,
	MLXIO_ERR_LOAD_DRIVER,
	MLXIO_ERR_MDD_OPEN,
	MLXIO_ERR_MLXM_OPEN,
	MLXIO_ERR_PREPARE,
	MLXIO_ERR_START,
	MLXIO_ERR_CHANNEL_TYPE,
	MLXIO_ERR_TRIGGERTASK,
	MLXIO_ERR_OPEN_TRIGGER,
	MLXIO_ERR_OPEN_SAMPTRIG,
	MLXIO_ERR_PRETRIGGER,
	MLXIO_ERR_INVALID_HANDLE,
	MLXIO_ERR_SAMPLE_RATE,
	MLXIO_ERR_MEMORY,
	MLXIO_ERR_TOO_MUCH_OUTPUTS,
	MLXIO_ERR_INVALID_CHANNEL,

	MLXIO_ERR_RELOAD = 32,
	MLXIO_ERR_OPEN_OUTPUT = 48,
	MLXIO_ERR_OPEN_INPUT = 64,
	
	MLXIO_ERR_NEXT = 80
};

#define	MLXIO_BUF_OVERFLOW	0x0001
#define	MLXIO_BUF_SPACE		0x0002
#define	MLXIO_BUF_TRANSFER	0x0004

#define	TRIGACT_START			0x0000
#define	TRIGACT_STOP			0x0001

#define	TRIGMODE_LIMIT_GT		0x0000
#define	TRIGMODE_LIMIT_LT		0x0001

#define	TRIGMODE_ONE_BIT_SET		0x0000
#define	TRIGMODE_ONE_BIT_CLR		0x0001
#define	TRIGMODE_ALL_BITS_SET	0x0080
#define	TRIGMODE_ALL_BITS_CLR	0x0081

typedef	void  (MLXIO_CALLBACK *MLXIOCHANCALLBACK)
	(HMLXIO hChan);

typedef void  (MLXIO_CALLBACK *MLXIOERRORCALLBACK)
	(USHORT card);

typedef void  (MLXIO_CALLBACK *MLXIOSTARTCALLBACK)
	(USHORT card);

typedef void  (MLXIO_CALLBACK *MLXIOSTOPCALLBACK)
	(USHORT card);

/*************************************************************************
*           procedures
*************************************************************************/

/*************************************************************************
*	mlxio_set_driver_path
*
*	PURPOSE
*	sets path where to find MDDs. If not specified, 
*  registry is searched for HKEY_LOCAL_MACHINE\SOFTWARE\SORCUS\SNW32
*  ml?_mdd_path
*
*	PARAMETER
*	-	path		Pointer to string containing path name
*	
*	RETURN
*	none
*
*************************************************************************/
MLXIO_API void		MLXIO_FUNC	mlxio_set_driver_path 
	(CHAR *path);

/*************************************************************************
*	mlxio_initialize
*
*	PURPOSE
*	initializes measurement parameters:
*	-	freq:		base frequency for data acquisition
*	-	bufsize: length of data buffer for each channel
*	-  mode:		not defined yet, please set to 0
*
*	PARAMETER
*	
*	RETURN
*	none
*
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_initialize 
	(double freq, ULONG bufsize, ULONG mode);

/*************************************************************************
*	mlxio_open_input_channel
*
*	PURPOSE
*	opens a MDD channel and allocates a ring buffer.
*************************************************************************/
MLXIO_API HMLXIO	MLXIO_FUNC  mlxio_open_input_channel 
	(USHORT usMDD, USHORT usStrucSize, void *pCPS, USHORT rate);

/*************************************************************************
*	mlxio_open_output_channel
*
*	PURPOSE
*	opens a MDD channel and allocates a ring buffer.
*************************************************************************/
MLXIO_API HMLXIO	MLXIO_FUNC  mlxio_open_output_channel 
	(USHORT usMDD, USHORT usStrucSize, void *pCPS, USHORT rate);

/*************************************************************************
*	mlxio_open_sample_trigger
*
*	PURPOSE
*	opens a sample trigger channel for the specified module.
*   The module is triggered at the beginning of the sample cycle.
*************************************************************************/
MLXIO_API HSAMPTRIG	MLXIO_FUNC  mlxio_open_sample_trigger 
	(USHORT usMDD, USHORT usStrucSize, void *pCPS, USHORT rate, ULONG trigval);

/*************************************************************************
*	mlxio_get_mdd_handle
*
*	PURPOSE
*	returns handle of attached MDD channel
*************************************************************************/
MLXIO_API HMDD8	MLXIO_FUNC  mlxio_get_mdd_handle 
	(HMLXIO hmlxio);

/*************************************************************************
*	mlxio_get_data_size
*
*	PURPOSE
*	returns number of bytes per sample for specified channel
*************************************************************************/
MLXIO_API USHORT	MLXIO_FUNC	mlxio_get_data_size 
	(HMLXIO hmlxio);

/*************************************************************************
*	mlxio_write_data
*
*	PURPOSE
*	write a data block of output samples into ring buffer.
*	When all previously opened buffers contain output data,
*	bundled blocks are transfered to the board
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_write_data 
	(HMLXIO hmlxio, void *databuffer, ULONG numofbytes, ULONG *error);

/*************************************************************************
*	mlxio_read_data
*
*	PURPOSE
*	read data block from ring buffer. Ring buffer is automatically
*	filled under interrupt control
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_read_data
	(HMLXIO hmlxio, void *databuffer, ULONG numofbytes, ULONG *error, ULONG *timebase);

/*************************************************************************
*	mlxio_start_measurement
*
*	PURPOSE
*	start data acquisition directly or begins waiting for start 
*  trigger event (if one is defined)
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_start_measurement 
	(void);

/*************************************************************************
*	mlxio_stop_measurement
*
*	PURPOSE
*	stop data acquisition
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_stop_measurement 
	(void);

/*************************************************************************
*	mlxio_get_acquisition_state
*
*	PURPOSE
*	returns state of data acquisition
*  0:      stopped by mlxio_stop_measurement or not started yet
*  1:      waiting for start trigger
*  2:      data acquisition running
*  3:      data acquisition stopped by stop trigger
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_get_acquisition_state 
	(void);

/*************************************************************************
*	mlxio_get_channel_state
*
*	PURPOSE
*	returns free/used space and error state
*************************************************************************/
MLXIO_API void	MLXIO_FUNC	mlxio_get_channel_state 
	(HMLXIO hmlxio, ULONG *free, ULONG *used, ULONG *error);

/*************************************************************************
*	mlxio_close_channel
*
*	PURPOSE
*	close any previously opened channel. 
*  Channel can be of type HMLXIO, HMLXTRIG or HMDD8
*************************************************************************/
MLXIO_API void		MLXIO_FUNC	mlxio_close_channel 
	(HMLXIO hmlxio);

/*************************************************************************
*	mlxio_set_chan_callback   (optional!!!)
*
*	PURPOSE
*	user program can set a function to be called when 
*	- input data are available (input channels)
*	- output buffer has to be filled (output channels)
*************************************************************************/
MLXIO_API void		MLXIO_FUNC	mlxio_set_chan_callback
	(HMLXIO hmlxio, MLXIOCHANCALLBACK pfnCallback);

/*************************************************************************
*	mlxio_set_start_callback   (optional!!!)
*
*	PURPOSE
*	user program can set a function to be called when 
*	a start request is received from an input module
*************************************************************************/
MLXIO_API void mlxio_set_start_callback
	(MLXIOSTARTCALLBACK pfnCallback);

/*************************************************************************
*	mlxio_set_stop_callback   (optional!!!)
*
*	PURPOSE
*	user program can set a function to be called when 
*	a stop request is received from an input module
*************************************************************************/
MLXIO_API void mlxio_set_stop_callback
	(MLXIOSTARTCALLBACK pfnCallback);

/*************************************************************************
*	mlxio_set_error_callback   (optional!!!)
*
*	PURPOSE
*	user program can set a function to be called when 
*	a error message is received from an input module
*************************************************************************/
MLXIO_API void mlxio_set_error_callback
	(MLXIOERRORCALLBACK pfnCallback);

/*************************************************************************
*	mlxio_set_trigger_mode
*
*	PURPOSE
*	specify pre- and posttrigger times (in units of base sampling rate
*  defined in mlxio_initialize)
*
*	global:	0:  trigger event starts/stops acquisition on actual board
*				1:  trigger event starts/stops acquisition on all used boards
*
*  
*************************************************************************/
MLXIO_API void	 MLXIO_FUNC  mlxio_set_trigger_mode
	(ULONG pretrigger, ULONG posttrigger, BOOL global);

/*************************************************************************
*	mlxio_define_limit_trigger
*
*	PURPOSE
*	creates a trigger object checking an analog trigger signal. 
*
*  hSignal:	 Handle of the channel to be checked:
*				 can be a previously opened input signal
*				 (handle of type HMLXIO, returned by mlxio_open_input_channel)
*				 or a handle returned by mdd8_open_channel.
*  action:   0x00  (TRIGACT_START)        trigger event starts acquisition
*				 0x01  (TRIGACT_STOP)         trigger event stops acquisition
*  mode:     0     (TRIGMODE_LIMIT_GT)    check if analog signal is greater
*														than specified limit
*				 1     (TRIGMODE_LIMIT_LT)    check if analog signal is less 
*														than specified limit
*	limit:	 value to be checked for.
*				 if trigger_mode TRIGMODE_LIMIT_GT is specified, this value
*				 must be exceeded to cause a trigger event.
*  min_time: 0:  exceeding limit immediately causes trigger event
*				 >0: trigger condition must be true for min. base clock ticks
*					  before trigger event is generated.
*  hysteresis:
*				 e.g. trigger_mode = TRIGMODE_LIMIT_GT: if a value
*				 less than 'limit' is specified, signal must return to 
*				 'hysteresis' value before the next trigger event can be
*				 generated. if 'hysteresis' is equal to or greater than 
*				 'limit', no hysteresis check is performed.
*
*	return value:	0    : could not create trigger object
*                 != 0 : handle of trigger object
*						
*************************************************************************/
MLXIO_API HMLXTRIG	MLXIO_FUNC mlxio_define_limit_trigger
	(void *hSignal, USHORT action, USHORT mode, 
	 SHORT limit, USHORT min_time, SHORT hysteresis);

/*************************************************************************
*	mlxio_define_bitmask_trigger
*
*	PURPOSE
*	creates a trigger object checking a group of digital signals.
*
*  hSignal:	 Handle of the channel to be checked:
*				 can be a previously opened input signal
*				 (handle of type HMLXIO, returned by mlxio_open_input_channel)
*				 or a handle returned by mdd8_open_channel.
*
*  action:   0x00  (TRIGACT_START)        trigger event starts acquisition
*				 0x01  (TRIGACT_STOP)         trigger event stops acquisition
*
*  mode:     0x00  (TRIGMODE_ONE_BIT_SET)	 check if at least one bit (specified
*														 in bitmask) is set in the signal block
*				 0x01  (TRIGMODE_ONE_BIT_CLR)	 check if at least one bit (specified
*														 in bitmask) is cleared in signal block
*				 0x80  (TRIGMODE_ALL_BITS_SET) check if all bits (specified in 
*														 bitmask) are set in the signal block
*				 0x81  (TRIGMODE_ALL_BITS_CLR) check if all bits (specified in
*														 bitmask) are cleared in signal block
*
*  bitmask:  compare value
*
*  min_time: 0:  bitmask match immediately causes trigger event
*				 >0: trigger condition must be true for min. base clock ticks
*					  before trigger event is generated.
*
*	return value:	0    : could not create trigger object
*                 != 0 : handle of trigger object
*						
*************************************************************************/
MLXIO_API HMLXTRIG  MLXIO_FUNC mlxio_define_bitmask_trigger
	(void *hSignal, USHORT action, USHORT mode, USHORT bitmask, USHORT min_time);

/*************************************************************************
*	mlxio_define_trigger
*
*	PURPOSE
*	creates a trigger object based on a CPS-structure for the trigger MDD.
*  (for SORCUS internal use only!)
*
*  hSignal:	 Handle of the channel to be checked:
*				 can be a previously opened input signal
*				 (handle of type HMLXIO, returned by mlxio_open_input_channel)
*				 or a handle returned by mdd8_open_channel.
*  
*  sizecps:  length (in bytes) of cps structure
*
*  pcps:		 pointer to cps structure for trigger MDD
*
*	return value:	0    : could not create trigger object
*                 != 0 : handle of trigger object
*						
*************************************************************************/

MLXIO_API HMLXTRIG  MLXIO_FUNC mlxio_define_trigger
	(void *hSignal, USHORT size_cps, void *pcps);

/*************************************************************************
*	mlxio_reload
*
*	PURPOSE
*	opens all configured channels on selected board
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_reload 
	(void);

/*************************************************************************
*	mlxio_close_all
*
*	PURPOSE
*	free all resources used by MLXIO.DLL 
*************************************************************************/
MLXIO_API ULONG	MLXIO_FUNC	mlxio_close_all	
	(void);

/*************************************************************************
*	mlxio_reset_error
*
*	PURPOSE
*	resets error state of an I/O channel
*************************************************************************/
MLXIO_API	void	MLXIO_FUNC	mlxio_reset_error 
	(HMLXIO hmlxio);

/*************************************************************************
*	mlxio_set_private_data
*
*	PURPOSE
*	user program can save a 32-bit-value for each I/O channel to identify
*  it in callback functions
*************************************************************************/
MLXIO_API	void	MLXIO_FUNC	mlxio_set_private_data 
	(HMLXIO hmlxio, ULONG ulPrivate);

/*************************************************************************
*	mlxio_get_private_data
*
*	PURPOSE
*	read back private 32-bit-value of I/O channel
*************************************************************************/
MLXIO_API	ULONG	MLXIO_FUNC	mlxio_get_private_data 
	(HMLXIO hmlxio);

/*************************************************************************
*	mlxio_get_previous_error
*
*	PURPOSE
*	returns the error state of the previous open-function.
*	Can be called after an open-function has returned a NULL handle
*************************************************************************/
MLXIO_API	ULONG	MLXIO_FUNC	mlxio_get_previous_error (void); 

#ifdef __cplusplus
}
#endif

#endif

// end of file: MLXIO.H
